@@ -27,7 +27,7 @@ sub new
 sub isa { Excel::Template::Factory::isa(@_) }
 sub is_embedded { Excel::Template::Factory::is_embedded(@_) }
 
-sub calculate { ($_[1])->get(@_[0,2]) }
+#sub calculate { ($_[1])->get(@_[0,2]) }
 #{
 #    my $self = shift;
 #    my ($context, $attr) = @_;
